"""
Written by Matteo Dunnhofer - 2019

Class that defines an expert tracker
"""
import os
import numpy as np
from got10k.trackers import Tracker

class DemoTracker(object):

	def __init__(self, cfg, name, dataset):
		self.cfg = cfg
		self.name = name
		self.dataset = dataset

		self.color = None

		self.tracker_path = os.path.join(self.cfg.DATA_PATH, 'results', self.dataset, self.name)

		self.tot_ious = []

	def load_predictions(self, seq_name, init_idx=0, end_idx=-1):
		"""
		Load the predictions of the tracker for the given sequence
		"""
		self.current_seq = seq_name
		
		if 'GOT-10k' in self.dataset:
			f_name = seq_name + '/'+ seq_name + '_001'
		else:
			f_name = seq_name
		
		self.seq_pred_file_path = os.path.join(self.tracker_path, f_name + '.txt')

		with open(self.seq_pred_file_path) as f:
			content = f.readlines()

		self.predictions = []
		self.ious = []	

		for c in content:
			ccs = c.split(',')
			x, y, w, h = float(ccs[0]), float(ccs[1]), float(ccs[2]), float(ccs[3])

			self.predictions.append([x, y, w, h])

		if end_idx > 0:
			self.predictions = self.predictions[init_idx:end_idx]

		return self.predictions

	def get_pred(self, idx):
		"""
		Return the idx prediction of the tracker
		"""
		return self.predictions[idx]

	def add_iou(self, iou):
		"""
		Add the computed iou
		"""
		self.ious.append(iou)
		self.tot_ious.append(iou)


class ResultsTracker(object):

	def __init__(self, name):
		self.name = name

	def init(self, image, bbox, **kwargs):
		#print(kwargs)
		#print(kwargs['result_dir'])
		#print(kwargs['seq_name'])
		result_dir = kwargs['result_dir']
		seq_name = kwargs['seq_name']
		seq_results_path = os.path.join(result_dir, self.name, seq_name + '.txt')
		#print(seq_results_path)
		self.result = self.load_predictions(seq_results_path)

		self.step = 0

	def update(self, image):
		self.step += 1

		return np.array(self.result[self.step])

	def load_predictions(self, result_file_path):
		"""
		Load the predictions of the tracker for the given sequence
		"""

		#if 'GOT-10k' in self.dataset:
		#	f_name = seq_name + '/' + seq_name + '_001'
		#else:
		#	f_name = seq_name

		#self.seq_pred_file_path = os.path.join(self.tracker_path, f_name + '.txt')

		with open(result_file_path) as f:
			content = f.readlines()

			f.close()

		predictions = []

		for c in content:
			ccs = c.split(',')
			x, y, w, h = float(ccs[0]), float(ccs[1]), float(ccs[2]), float(ccs[3])

			predictions.append([x, y, w, h])

		return predictions


